Module process

Module process 

Structs

ProcessGuard
A guard that manages the lifecycle of a browser process. When dropped, it kills the process unless it was detached and NOT meant to be killed.
ProcessRegistry

Statics

REGISTERED_PIDS
Global registry of active browser PIDs for emergency cleanup.

Functions

cleanup_all
Global cleanup function to be called on application exit if desired.
kill_pid
Forcefully kills a process by PID.
spawn_detached
Spawns a detached process that can outlive the parent.