pub fn spawn_detached(cmd: Command) -> XcelerateResult<u32>Expand description
Spawns a detached process that can outlive the parent.
Returns the PID of the spawned process.
pub fn spawn_detached(cmd: Command) -> XcelerateResult<u32>Spawns a detached process that can outlive the parent.
Returns the PID of the spawned process.