pub struct ProcessGuard {
pub pid: u32,
pub auto_kill: bool,
}Expand description
A guard that manages the lifecycle of a browser process. When dropped, it kills the process unless it was detached and NOT meant to be killed.
Fields
pid: u32auto_kill: boolTrait Implementations